@@ -98,6 +98,7 @@ from neutron_lib.api.definitions import sort_key_validation
 from neutron_lib.api.definitions import sorting
 from neutron_lib.api.definitions import standard_attr_segment
 from neutron_lib.api.definitions import subnet
+from neutron_lib.api.definitions import subnet_dns_publish_fixed_ip
 from neutron_lib.api.definitions import subnet_onboard
 from neutron_lib.api.definitions import subnet_segmentid_enforce
 from neutron_lib.api.definitions import subnet_segmentid_writable
@@ -202,6 +203,7 @@ _ALL_API_DEFINITIONS = {
     sorting,
     standard_attr_segment,
     subnet,
+    subnet_dns_publish_fixed_ip,
     subnet_onboard,
     subnet_segmentid_enforce,
     subnet_segmentid_writable,
